==> jc-1.4.0.tar.gz: soot/util/dot/DotGraphEdge.h <==
// public class soot.util.dot.DotGraphEdge

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 71029e81ee1c3f7e soot_util_dot_DotGraphEdge

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_dot_DotGraphEdge_H_
#define _JC_soot_util_dot_DotGraphEdge_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_util_dot_DotGraphNode$object;

// Typedefs
typedef struct _jc_soot_util_dot_DotGraphEdge$sub_refs	_jc_soot_util_dot_DotGraphEdge$sub_refs;
typedef struct _jc_soot_util_dot_DotGraphEdge$sub_nonrefs	_jc_soot_util_dot_DotGraphEdge$sub_nonrefs;
typedef struct _jc_soot_util_dot_DotGraphEdge$refs	_jc_soot_util_dot_DotGraphEdge$refs;
typedef struct _jc_soot_util_dot_DotGraphEdge$nonrefs	_jc_soot_util_dot_DotGraphEdge$nonrefs;
typedef struct _jc_soot_util_dot_DotGraphEdge$object	_jc_soot_util_dot_DotGraphEdge$object;

typedef const struct _jc_soot_util_dot_DotGraphEdge$vmethods	_jc_soot_util_dot_DotGraphEdge$vmethods;
typedef const struct _jc_soot_util_dot_DotGraphEdge$vtable	_jc_soot_util_dot_DotGraphEdge$vtable;
typedef const struct _jc_soot_util_dot_DotGraphEdge$vtype	_jc_soot_util_dot_DotGraphEdge$vtype;

// Constructors
extern void _jc_soot_util_dot_DotGraphEdge$method$_init$73c431b001de62a6(_jc_env *, struct _jc_soot_util_dot_DotGraphEdge$object *, struct _jc_soot_util_dot_DotGraphNode$object *, struct _jc_soot_util_dot_DotGraphNode$object *);
extern void _jc_soot_util_dot_DotGraphEdge$method$_init$dec4bba48ab9fd8d(_jc_env *, struct _jc_soot_util_dot_DotGraphEdge$object *, struct _jc_soot_util_dot_DotGraphNode$object *, struct _jc_soot_util_dot_DotGraphNode$object *, jboolean);

// Virtual methods
extern void _jc_soot_util_dot_DotGraphEdge$method$render$d3bab9d003cfd984(_jc_env *, struct _jc_soot_util_dot_DotGraphEdge$object *, struct _jc_java_io_OutputStream$object *, jint);
extern void _jc_soot_util_dot_DotGraphEdge$method$setAttribute$72015e8eab720287(_jc_env *, struct _jc_soot_util_dot_DotGraphEdge$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);
extern void _jc_soot_util_dot_DotGraphEdge$method$setLabel$cc08d442c8afc167(_jc_env *, struct _jc_soot_util_dot_DotGraphEdge$object *, struct _jc_java_lang_String$object *);
extern void _jc_soot_util_dot_DotGraphEdge$method$setStyle$dde4933900b25e7b(_jc_env *, struct _jc_soot_util_dot_DotGraphEdge$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_util_dot_DotGraphEdge$method_info$render$d3bab9d003cfd984;
extern _jc_method _jc_soot_util_dot_DotGraphEdge$method_info$setAttribute$72015e8eab720287;
extern _jc_method _jc_soot_util_dot_DotGraphEdge$method_info$setLabel$cc08d442c8afc167;
extern _jc_method _jc_soot_util_dot_DotGraphEdge$method_info$setStyle$dde4933900b25e7b;

// Virtual methods structure
struct _jc_soot_util_dot_DotGraphEdge$vmethods {
	void	(*render$d3bab9d003cfd984)(_jc_env *, struct _jc_soot_util_dot_DotGraphEdge$object *, struct _jc_java_io_OutputStream$object *, jint);
	void	(*setAttribute$72015e8eab720287)(_jc_env *, struct _jc_soot_util_dot_DotGraphEdge$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);
	void	(*setLabel$cc08d442c8afc167)(_jc_env *, struct _jc_soot_util_dot_DotGraphEdge$object *, struct _jc_java_lang_String$object *);
	void	(*setStyle$dde4933900b25e7b)(_jc_env *, struct _jc_soot_util_dot_DotGraphEdge$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_soot_util_dot_DotGraphEdge$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_dot_DotGraphEdge$vmethods	soot_util_dot_DotGraphEdge;
};

// Vtype
struct _jc_soot_util_dot_DotGraphEdge$vtype {
	_jc_type			type;
	_jc_soot_util_dot_DotGraphEdge$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_dot_DotGraphEdge$sub_refs {
	struct _jc_soot_util_dot_DotGraphNode$object	*start;
	struct _jc_soot_util_dot_DotGraphNode$object	*end;
	struct _jc_object	*attributes;
};

// Reference instance fields (object)
struct _jc_soot_util_dot_DotGraphEdge$refs {
    _jc_soot_util_dot_DotGraphEdge$sub_refs	soot_util_dot_DotGraphEdge;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_dot_DotGraphEdge$sub_nonrefs {
	jboolean	isDirected;
};

// Non-reference instance fields (object)
struct _jc_soot_util_dot_DotGraphEdge$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_dot_DotGraphEdge$sub_nonrefs	soot_util_dot_DotGraphEdge;
};

// Object instance structure
struct _jc_soot_util_dot_DotGraphEdge$object {
	_jc_soot_util_dot_DotGraphEdge$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_dot_DotGraphEdge$vtype	*vtype;
	_jc_soot_util_dot_DotGraphEdge$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_dot_DotGraphEdge$vtype _jc_soot_util_dot_DotGraphEdge$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_dot_DotGraphEdge, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_dot_DotGraphEdge$class_object;

#endif	/* _JC_soot_util_dot_DotGraphEdge_H_ */

==> jc-1.4.6.tar.gz: soot/util/dot/DotGraphEdge.h <==
// public class soot.util.dot.DotGraphEdge

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 71029e81ee1c3f7e soot_util_dot_DotGraphEdge

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_dot_DotGraphEdge_H_
#define _JC_soot_util_dot_DotGraphEdge_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_util_dot_DotGraphNode$object;

// Typedefs
typedef struct _jc_soot_util_dot_DotGraphEdge$sub_refs	_jc_soot_util_dot_DotGraphEdge$sub_refs;
typedef struct _jc_soot_util_dot_DotGraphEdge$sub_nonrefs	_jc_soot_util_dot_DotGraphEdge$sub_nonrefs;
typedef struct _jc_soot_util_dot_DotGraphEdge$refs	_jc_soot_util_dot_DotGraphEdge$refs;
typedef struct _jc_soot_util_dot_DotGraphEdge$nonrefs	_jc_soot_util_dot_DotGraphEdge$nonrefs;
typedef struct _jc_soot_util_dot_DotGraphEdge$object	_jc_soot_util_dot_DotGraphEdge$object;

typedef const struct _jc_soot_util_dot_DotGraphEdge$vmethods	_jc_soot_util_dot_DotGraphEdge$vmethods;
typedef const struct _jc_soot_util_dot_DotGraphEdge$vtable	_jc_soot_util_dot_DotGraphEdge$vtable;
typedef const struct _jc_soot_util_dot_DotGraphEdge$vtype	_jc_soot_util_dot_DotGraphEdge$vtype;

// Constructors
extern void _jc_soot_util_dot_DotGraphEdge$method$_init$73c431b001de62a6(_jc_env *, struct _jc_soot_util_dot_DotGraphEdge$object *, struct _jc_soot_util_dot_DotGraphNode$object *, struct _jc_soot_util_dot_DotGraphNode$object *) _JC_JCNI_ATTR;
extern void _jc_soot_util_dot_DotGraphEdge$method$_init$dec4bba48ab9fd8d(_jc_env *, struct _jc_soot_util_dot_DotGraphEdge$object *, struct _jc_soot_util_dot_DotGraphNode$object *, struct _jc_soot_util_dot_DotGraphNode$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_util_dot_DotGraphEdge$method$render$d3bab9d003cfd984(_jc_env *, struct _jc_soot_util_dot_DotGraphEdge$object *, struct _jc_java_io_OutputStream$object *, jint) _JC_JCNI_ATTR;
extern void _jc_soot_util_dot_DotGraphEdge$method$setAttribute$72015e8eab720287(_jc_env *, struct _jc_soot_util_dot_DotGraphEdge$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_soot_util_dot_DotGraphEdge$method$setLabel$cc08d442c8afc167(_jc_env *, struct _jc_soot_util_dot_DotGraphEdge$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_soot_util_dot_DotGraphEdge$method$setStyle$dde4933900b25e7b(_jc_env *, struct _jc_soot_util_dot_DotGraphEdge$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_util_dot_DotGraphEdge$method_info$render$d3bab9d003cfd984;
extern _jc_method _jc_soot_util_dot_DotGraphEdge$method_info$setAttribute$72015e8eab720287;
extern _jc_method _jc_soot_util_dot_DotGraphEdge$method_info$setLabel$cc08d442c8afc167;
extern _jc_method _jc_soot_util_dot_DotGraphEdge$method_info$setStyle$dde4933900b25e7b;

// Virtual methods structure
struct _jc_soot_util_dot_DotGraphEdge$vmethods {
	void	(*render$d3bab9d003cfd984)(_jc_env *, struct _jc_soot_util_dot_DotGraphEdge$object *, struct _jc_java_io_OutputStream$object *, jint) _JC_JCNI_ATTR;
	void	(*setAttribute$72015e8eab720287)(_jc_env *, struct _jc_soot_util_dot_DotGraphEdge$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*setLabel$cc08d442c8afc167)(_jc_env *, struct _jc_soot_util_dot_DotGraphEdge$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*setStyle$dde4933900b25e7b)(_jc_env *, struct _jc_soot_util_dot_DotGraphEdge$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_util_dot_DotGraphEdge$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_dot_DotGraphEdge$vmethods	soot_util_dot_DotGraphEdge;
};

// Vtype
struct _jc_soot_util_dot_DotGraphEdge$vtype {
	_jc_type			type;
	_jc_soot_util_dot_DotGraphEdge$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_dot_DotGraphEdge$sub_refs {
	struct _jc_soot_util_dot_DotGraphNode$object	*start;
	struct _jc_soot_util_dot_DotGraphNode$object	*end;
	struct _jc_object	*attributes;
};

// Reference instance fields (object)
struct _jc_soot_util_dot_DotGraphEdge$refs {
    _jc_soot_util_dot_DotGraphEdge$sub_refs	soot_util_dot_DotGraphEdge;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_dot_DotGraphEdge$sub_nonrefs {
	jboolean	isDirected;
};

// Non-reference instance fields (object)
struct _jc_soot_util_dot_DotGraphEdge$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_dot_DotGraphEdge$sub_nonrefs	soot_util_dot_DotGraphEdge;
};

// Object instance structure
struct _jc_soot_util_dot_DotGraphEdge$object {
	_jc_soot_util_dot_DotGraphEdge$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_dot_DotGraphEdge$vtype	*vtype;
	_jc_soot_util_dot_DotGraphEdge$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_dot_DotGraphEdge$vtype _jc_soot_util_dot_DotGraphEdge$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_dot_DotGraphEdge, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_dot_DotGraphEdge$class_object;

#endif	/* _JC_soot_util_dot_DotGraphEdge_H_ */
